@@ -124,7 +124,7 @@ class WorxCloud(object):
         if isinstance(self._dev_id, type(None)):
             self._dev_id = 0
 
-        self.authenticate
+        self.authenticate()
 
         self.connect(self._dev_id, self._verify_ssl)
         self.update()
@@ -135,13 +135,12 @@ class WorxCloud(object):
         """Called on end of with statement."""
         self.disconnect()
 
-    @property
     def authenticate(self) -> bool:
         """Authenticate against the API."""
         auth = self._authenticate()
         if auth is False:
             self._auth_result = False
-            raise AuthenticationError("Unauthorized")
+            raise AuthorizationError("Unauthorized")
 
         self._auth_result = True
 
@@ -497,6 +496,13 @@ class WorxCloud(object):
         else:
             raise OfflineError("The device is currently offline, no action was sent.")
 
+    def safehome(self):
+        """Stop and go home (with blades off)."""
+        if self.online:
+            self._mqtt.publish(self.mqtt_in, '{"cmd":9}', qos=0, retain=False)
+        else:
+            raise OfflineError("The device is currently offline, no action was sent.")
+
     def raindelay(self, rain_delay: str | int) -> None:
         """Set new rain delay."""
         if self.online:
